@@ -24,17 +24,19 @@ use constant DEFAULT_QUOTE_KEYS => 0;
 use constant DEFAULT_BASE_DIR => '/tmp';
 use constant MAX_FRAME => 10;
 
+use constant DEFAULT_HISTORY_LENGTH => 0;
+
 =head1 NAME
 
 Log::AutoDump - Log with automatic dumping of references and objects.
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 $VERSION = eval $VERSION;
 
@@ -141,14 +143,16 @@ sub new
     }
         
     my $self = {
-         level      => exists $args{ level } ? $args{ level } : DEFAULT_LEVEL,
-         dumps      => exists $args{ dumps } ? $args{ dumps } : 1,
-         dump_depth => $args{ dump_depth } || 0,
-         sort_keys  => exists $args{ sort_keys }  ? $args{ sort_keys }  : DEFAULT_SORT_KEYS,
-         quote_keys => exists $args{ quote_keys } ? $args{ quote_keys } : DEFAULT_QUOTE_KEYS,
-         filename   => $args{ filename },
-         autoflush  => exists $args{ autoflush } ? $args{ autoflush } : 1,
-        _fh         => undef,
+         level          => exists $args{ level } ? $args{ level } : DEFAULT_LEVEL,
+         history_length => exists $args{ history_length } ? $args{ history_length } : DEFAULT_HISTORY_LENGTH,
+         history        => [],
+         dumps          => exists $args{ dumps } ? $args{ dumps } : 1,
+         dump_depth     => $args{ dump_depth } || 0,
+         sort_keys      => exists $args{ sort_keys }  ? $args{ sort_keys }  : DEFAULT_SORT_KEYS,
+         quote_keys     => exists $args{ quote_keys } ? $args{ quote_keys } : DEFAULT_QUOTE_KEYS,
+         filename       => $args{ filename },
+         autoflush      => exists $args{ autoflush } ? $args{ autoflush } : 1,
+        _fh             => undef,
     };
 
     my $fh = IO::File->new( ">> " . $self->{filename} );
@@ -181,6 +185,44 @@ sub level
     return $self->{ level };
 }
 
+=head3 history_length
+
+Controls how many historical log events to remember.
+
+This is the number of events, not number of statments or dumps.
+
+If a debug statement includes 3 messages/objects, all 3 are stored in one unit of length.
+
+ $log->history_length( 10 );
+
+=cut
+
+sub history_length
+{
+    my ( $self, $arg ) = @_;
+    $self->{ history_length } = $arg if defined $arg;
+    return $self->{ history_length };
+}
+
+=head3 history
+
+The list of historical statements/objects.
+
+Each point in the history is an arrayref of statements/objects.
+
+This is only a getter, the history is accumulated internally.
+
+ $log->history;
+
+=cut
+
+sub history
+{
+    my $self = shift;
+
+    return $self->{ history };
+}
+
 =head3 dumps
 
 Controls whether references and objects are dumped or not.
@@ -397,6 +439,16 @@ sub msg
 
     print $fh $msg;
 
+    if ( scalar @{ $self->{ history } } >= $self->{ history_length } )
+    {
+        shift @{ $self->{ history } };
+    }
+
+    if ( scalar @{ $self->{ history } } < $self->{ history_length } )
+    {
+        push @{ $self->{ history } }, \@things;
+    }
+
     return $self;
 }
 
